.. fixerio documentation master file, created by
   sphinx-quickstart on Sat May 28 13:12:00 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. include:: api_reference.rst

.. include:: ../CHANGELOG.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

